@@ -66,7 +66,7 @@ function RBlockListQt(parent, addListener, showHeader) {
         var adapter = new RBlockListenerAdapter();
         appWin.addBlockListener(adapter);
         adapter.blocksUpdated.connect(this, "updateBlocks");
-        adapter.currentBlockSet.connect(this, "updateBlocks");
+        adapter.currentBlockSet.connect(this, "updateCurrentBlock");
         adapter.blocksCleared.connect(this, "clearBlocks");
     }
 
@@ -74,6 +74,9 @@ function RBlockListQt(parent, addListener, showHeader) {
     this.itemColumnClicked.connect(this, "itemColumnClickedSlot");
     this.itemSelectionChanged.connect(this, "blockActivated");
     this.basePath = includeBasePath;
+
+    this.currentItem = undefined;
+
 }
 
 RBlockListQt.prototype = new RTreeWidget();
@@ -171,10 +174,37 @@ RBlockListQt.prototype.filter = function(block) {
     return true;
 };
 
+RBlockListQt.prototype.updateCurrentBlock = function(documentInterface) {
+    var doc = documentInterface.getDocument();
+
+    // find item which was representing the current block before:
+    if (!isNull(this.currentItem)) {
+        // clear pen icon from item:
+        //var blockName = this.currentItem.data(BlockList.colName, Qt.UserRole);
+        //var block = doc.queryBlock(blockName);
+        //this.updateItemIcons(this.currentItem, block);
+        this.currentItem.setIcon(BlockList.colEdit, BlockList.iconEdit[0]);
+    }
+
+    // find item of current block:
+    this.currentItem = RBlockListQt.getItem(this, doc.getCurrentBlockName());
+    //for (var i=0; i<this.topLevelItemCount; i++) {
+    //    var item = this.topLevelItem(i);
+    //}
+
+    // add pen icon to item:
+    if (!isNull(this.currentItem)) {
+        this.currentItem.setIcon(BlockList.colEdit, BlockList.iconEdit[1]);
+    }
+};
+
 /**
  * Called when blocks are addded, edited or deleted. Updates the block list.
  */
 RBlockListQt.prototype.updateBlocks = function(documentInterface) {
+    this.currentItem = undefined;
+
+    RDebug.startTimer();
     this.di = documentInterface;
 
     var pos = this.verticalScrollBar().sliderPosition;
@@ -214,7 +244,6 @@ RBlockListQt.prototype.updateBlocks = function(documentInterface) {
     blockIds = this.sortBlocks(doc, blockIds);
 
     var currentBlockId = doc.getCurrentBlockId();
-    var currentItem = undefined;
     var selectedItem = undefined;
     for (i=0; i<blockIds.length; ++i) {
         var blockId = blockIds[i];
@@ -232,7 +261,7 @@ RBlockListQt.prototype.updateBlocks = function(documentInterface) {
         }
 
         if (currentBlockId===block.getId()) {
-            currentItem = item;
+            this.currentItem = item;
         }
     }
 
@@ -245,6 +274,7 @@ RBlockListQt.prototype.updateBlocks = function(documentInterface) {
     }
 
     this.blockActivated();
+    RDebug.stopTimer("block list update");
 };
 
 RBlockListQt.prototype.sortBlocks = function(doc, blockIds) {
@@ -279,13 +309,13 @@ RBlockListQt.prototype.createBlockItem = function(block) {
 };
 
 RBlockListQt.prototype.updateItemIcons = function(item, block) {
-    var iconName = autoIconPath(BlockList.includeBasePath + "/Visible%1.svg".arg(Number(!block.isFrozen())));
-    item.setIcon(BlockList.colVisible, new QIcon(iconName));
+    //var iconName = autoIconPath(BlockList.includeBasePath + "/Visible%1.svg".arg(Number(!block.isFrozen())));
+    item.setIcon(BlockList.colVisible, BlockList.iconVisible[Number(!block.isFrozen())]);
 
     var doc = this.di.getDocument();
     var currentBlockId = doc.getCurrentBlockId();
-    iconName = autoIconPath(BlockList.includeBasePath + "/Edit%1.svg".arg(Number(block.getId()===currentBlockId)));
-    item.setIcon(BlockList.colEdit, new QIcon(iconName));
+    //iconName = autoIconPath(BlockList.includeBasePath + "/Edit%1.svg".arg(Number(block.getId()===currentBlockId)));
+    item.setIcon(BlockList.colEdit, BlockList.iconEdit[Number(block.getId()===currentBlockId)]);
 };
 
 /**
@@ -314,11 +344,11 @@ RBlockListQt.prototype.itemColumnClickedSlot = function(item, column) {
         block.setFrozen(!block.isFrozen());
         var op = new RModifyObjectOperation(block, false);
         this.di.applyOperation(op);
-        this.updateBlocks(this.di);
+        //this.updateBlocks(this.di);
     } else if (column===BlockList.colEdit) {
         this.setCurrentItem(item);
         this.editBlock();
-        this.updateBlocks(this.di);
+        //this.updateBlocks(this.di);
     }
 
     this.blockActivated();
@@ -449,6 +479,16 @@ BlockList.colVisible=0;
 BlockList.colEdit=1;
 BlockList.colName=2;
 
+BlockList.iconVisible = [
+    new QIcon(autoIconPath(BlockList.includeBasePath + "/Visible0.svg")),
+    new QIcon(autoIconPath(BlockList.includeBasePath + "/Visible1.svg"))
+];
+
+BlockList.iconEdit = [
+    new QIcon(autoIconPath(BlockList.includeBasePath + "/Edit0.svg")),
+    new QIcon(autoIconPath(BlockList.includeBasePath + "/Edit1.svg"))
+];
+
 BlockList.getPreferencesCategory = function() {
     return [ qsTr("Widgets"), qsTr("Block List") ];
 };
